@@ -35,11 +35,15 @@ def load_sources_yaml_file(path: Optional[str] = None):
     Load the yaml sources file - this is in the format of one source file to load per line.
     :param path: The sources file path. Do not specify to use the latest default.
     :return: The contents of the sources file - expected a list of source file paths.
+    If the file path doesn't exist, None is returned.
     """
     if not path:
         path = get_latest_sources_yaml_file()
-    with open(path, 'r', encoding='utf-8') as infile:
-        return infile.read().split('\n')
+    try:
+        with open(path, 'r', encoding='utf-8') as infile:
+            return infile.read().split('\n')
+    except (TypeError, OSError):
+        return None
 
 
 def fetch_tournament_ids(save_path: Optional[str] = None) -> Set[str]:
@@ -71,7 +75,7 @@ def generate_new_sources_files(battlefy_ids: Collection[str], skip_redownload: b
     """
 
     # Current sources:
-    sources_contents = load_sources_yaml_file()
+    sources_contents = load_sources_yaml_file() or []
     battlefy_ids_len = len(battlefy_ids)
     print(f"{len(sources_contents)} sources loaded from current sources yaml. "
           f"{battlefy_ids_len} Battlefy Ids known. (Diff of {battlefy_ids_len - len(sources_contents)}).")
@@ -142,14 +146,14 @@ def generate_new_sources_files(battlefy_ids: Collection[str], skip_redownload: b
 
     # Take care of those pesky exceptions to the rule
     # statink folder is special
-    if './statink' in sources_contents:
+    if sources_contents and './statink' in sources_contents:
         statink_present = True
         sources_contents.remove('./statink')
     else:
         statink_present = False
 
     # Twitter goes last (but only if not dated)
-    if 'Twitter.json' in sources_contents[-1]:
+    if sources_contents and 'Twitter.json' in sources_contents[-1]:
         twitter_str = sources_contents[-1]
         sources_contents.remove(sources_contents[-1])
     else:
@@ -216,12 +220,12 @@ def _invoke_slapp(command: str):
     )
 
 
-def rebuild_sources(new_sources_file_path):
-    _invoke_slapp(f"--rebuild {new_sources_file_path}")
+def rebuild_sources(new_sources_file_path, verbose: bool = True):
+    _invoke_slapp(f"{'--verbose ' if verbose else ''}--rebuild {new_sources_file_path}")
 
 
-def patch_sources(new_sources_file_path):
-    _invoke_slapp(f"--patch {new_sources_file_path}")
+def patch_sources(new_sources_file_path, verbose: bool = True):
+    _invoke_slapp(f"{'--verbose ' if verbose else ''}--patch {new_sources_file_path}")
 
 
 _global_player_local_id_to_slapp_id = dict()
